==> haskell-indexed-traversable-instances-0.1.2-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-Jb68eS0lvU1qtgAO4ziE2
key:                  indexed-traversable-instances-0.1.2-Jb68eS0lvU1qtgAO4ziE2
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  333f38cf223a2751de86ea8821615022
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:         HSindexed-traversable-instances-0.1.2-Jb68eS0lvU1qtgAO4ziE2
depends:
    OneTuple-0.4.2-H2hq3WX7vAYH5Mde32s1b7 base-4.17.2.1
    indexed-traversable-0.1.4-FpAcbJlkQDVBCnOnkgXYhG
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    unordered-containers-0.2.20-A2tjqfQXDXnFd3Ae9FP0C3
    vector-0.13.2.0-5H8NMvQc0Ab8bNH9ZMgAUW

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-indexed-traversable-instances-0.1.2-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-LFduOpJnk06CQh6Uz2nRya
key:                  indexed-traversable-instances-0.1.2-LFduOpJnk06CQh6Uz2nRya
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  f5b9b8a38a6a1e088c372e5a68d437d0
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:
    HSindexed-traversable-instances-0.1.2-LFduOpJnk06CQh6Uz2nRya

depends:
    OneTuple-0.4.2-DwBf62X1oqOJ5vdkL5wCev base-4.17.2.1
    indexed-traversable-0.1.4-9eY2jWX2flnImgSA45MGyH
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    unordered-containers-0.2.20-5aRSzj1YCHv4h2N6lFa6Hx
    vector-0.13.2.0-BWMo7dqC00725tIPRLs4rJ

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
